@@ -1,6 +1,6 @@
 package Statocles::App::Static;
 # ABSTRACT: Manage static files like CSS, JS, images, and other untemplated content
-$Statocles::App::Static::VERSION = '0.035';
+$Statocles::App::Static::VERSION = '0.036';
 use Statocles::Base 'Class';
 extends 'Statocles::App';
 use Statocles::Page::File;
@@ -36,7 +36,7 @@ sub pages {
         }
 
         push @pages, Statocles::Page::File->new(
-            path => $path,
+            path => join( "/", $self->url_root, $path ),
             fh => $self->store->open_file( $path ),
         );
     }
@@ -56,7 +56,7 @@ Statocles::App::Static - Manage static files like CSS, JS, images, and other unt
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 DESCRIPTION
 
