@@ -1,6 +1,6 @@
 package Statocles::Page;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::VERSION = '0.035';
+$Statocles::Page::VERSION = '0.036';
 use Statocles::Base 'Role';
 use Statocles::Template;
 use Text::Markdown;
@@ -28,9 +28,11 @@ has path => (
 );
 
 
-has published => (
+has last_modified => (
     is => 'ro',
     isa => InstanceOf['Time::Piece'],
+    lazy => 1,
+    default => sub { Time::Piece->new },
 );
 
 
@@ -121,7 +123,7 @@ Statocles::Page - Render documents into HTML
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 DESCRIPTION
 
@@ -143,9 +145,9 @@ The application this page came from, so we can give it to the templates.
 
 The absolute URL path to save this page to.
 
-=head2 published
+=head2 last_modified
 
-The publish date/time of this page. A L<Time::Piece> object.
+The last modified date/time of this page. A L<Time::Piece> object.
 
 =head2 links
 
