@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::Document::VERSION = '0.035';
+$Statocles::Page::Document::VERSION = '0.036';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Text::Markdown;
@@ -30,6 +30,15 @@ has author => (
 );
 
 
+has '+last_modified' => (
+    lazy => 1,
+    default => sub {
+        my ( $self ) = @_;
+        $self->document->last_modified || Time::Piece->new;
+    },
+);
+
+
 has _tags => (
     is => 'ro',
     isa => LinkArray,
@@ -67,15 +76,6 @@ sub sections {
 }
 
 
-sub last_modified {
-    my ( $self ) = @_;
-    if ( my $dt = $self->published ) {
-        return $dt;
-    }
-    return $self->document->last_modified;
-}
-
-
 sub tags {
     my ( $self ) = @_;
     return @{ $self->_tags };
@@ -93,7 +93,7 @@ Statocles::Page::Document - Render documents into HTML
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 DESCRIPTION
 
@@ -113,6 +113,10 @@ The title of the page.
 
 The author of the page.
 
+=head2 last_modified
+
+Get the last modified date of this page by checking the document.
+
 =head2 tags
 
 The tag links for this document. An array of L<link objects|Statocles::Link>. The
@@ -137,11 +141,6 @@ Get the template variables for this page.
 Get a list of content divided into sections. The Markdown "---" marker divides
 sections.
 
-=head2 last_modified
-
-Get the last modified date of this page by checking the document or using the page's
-publish date.
-
 =head2 tags()
 
 Get the list of tags for this page.
