@@ -1,6 +1,6 @@
 package Statocles::Page::File;
 # ABSTRACT: A page wrapping a file (handle)
-$Statocles::Page::File::VERSION = '0.035';
+$Statocles::Page::File::VERSION = '0.036';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 
@@ -12,13 +12,6 @@ has fh => (
 );
 
 
-has last_modified => (
-    is => 'ro',
-    isa => InstanceOf['Time::Piece'],
-    default => sub { Time::Piece->new },
-);
-
-
 # XXX: This may have to be implemented in the future, to allow for some useful edge
 # cases.
 sub vars { die "Unimplemented" }
@@ -41,7 +34,7 @@ Statocles::Page::File - A page wrapping a file (handle)
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 SYNOPSIS
 
@@ -63,10 +56,6 @@ L<store|Statocles::Store> to another.
 
 The file handle containing the contents of the page. Required.
 
-=head2 last_modified
-
-The last modified time of the page.
-
 =head1 METHODS
 
 =head2 vars
