@@ -1,6 +1,6 @@
 package Statocles::Page::List;
 # ABSTRACT: A page presenting a list of other pages
-$Statocles::Page::List::VERSION = '0.035';
+$Statocles::Page::List::VERSION = '0.036';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use List::Util qw( max );
@@ -21,6 +21,15 @@ has [qw( next prev )] => (
 );
 
 
+has '+last_modified' => (
+    lazy => 1,
+    default => sub {
+        my ( $self ) = @_;
+        $self->pages->[0]->last_modified;
+    },
+);
+
+
 has '+search_change_frequency' => (
     default => sub { 'daily' },
 );
@@ -55,7 +64,7 @@ sub paginate {
             pages => [ @{$pages}[ @{ $sets[$i] } ] ],
             ( $next ? ( next => $next ) : () ),
             ( $i > 0 ? ( prev => $prev ) : () ),
-            published => $pages->[0]->last_modified,
+            last_modified => $pages->[0]->last_modified,
             %args,
         );
     }
@@ -71,12 +80,6 @@ sub vars {
     );
 }
 
-
-sub last_modified {
-    my ( $self ) = @_;
-    return $self->published || max map { $_->last_modified } @{ $self->pages };
-}
-
 1;
 
 __END__
@@ -89,7 +92,7 @@ Statocles::Page::List - A page presenting a list of other pages
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 DESCRIPTION
 
@@ -110,6 +113,11 @@ The path to the next page in the pagination series.
 
 The path to the previous page in the pagination series.
 
+=head2 last_modified
+
+Get the last modified date of this list. By default, this is the last modified date
+of the first page in the list of pages.
+
 =head2 search_change_frequency
 
 Override the default L<search_change_frequency|Statocles::Page/search_change_frequency>
@@ -145,11 +153,6 @@ page first (if any).
 
 Get the template variables for this page.
 
-=head2 last_modified
-
-Get the last modified date of this page. This will be the most recent last modified
-date of the pages inside this page.
-
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
