@@ -1,6 +1,6 @@
 package Statocles::Page::Plain;
 # ABSTRACT: A plain page (with templates)
-$Statocles::Page::Plain::VERSION = '0.035';
+$Statocles::Page::Plain::VERSION = '0.036';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 
@@ -13,13 +13,6 @@ has _content => (
 );
 
 
-has last_modified => (
-    is => 'ro',
-    isa => InstanceOf['Time::Piece'],
-    default => sub { Time::Piece->new },
-);
-
-
 sub content {
     return $_[0]->_content;
 }
@@ -36,7 +29,7 @@ Statocles::Page::Plain - A plain page (with templates)
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 SYNOPSIS
 
@@ -62,10 +55,6 @@ anything else) outside of Statocles.
 
 The content of the page, already rendered to HTML.
 
-=head2 last_modified
-
-The last modified time of the page.
-
 =head1 METHODS
 
 =head2 content
