@@ -1,6 +1,6 @@
 package Statocles::Template;
 # ABSTRACT: A template object to pass around
-$Statocles::Template::VERSION = '0.035';
+$Statocles::Template::VERSION = '0.036';
 use Statocles::Base 'Class';
 use Mojo::Template;
 use Scalar::Util qw( blessed );
@@ -106,7 +106,7 @@ sub _include {
                 content => $store->read_file( "$name" ),
                 store => $store,
             );
-            return $inner_tmpl->render( %$vars, %args );
+            return $inner_tmpl->render( %$vars, %args ) || '';
         }
 
         return $store->read_file( $name );
@@ -139,7 +139,7 @@ Statocles::Template - A template object to pass around
 
 =head1 VERSION
 
-version 0.035
+version 0.036
 
 =head1 DESCRIPTION
 
